.. _condition-api:

Condition API
=============

Condition API addresses the issues with the static code 
analyzers by providing Python objects that are are named
similarly as the components in string syntax. Condition 
API contains a collection of instances and functions that 
return instances of conditions. 

Here are some examples:

.. literalinclude:: /code/conds/api/simple.py
    :language: py
    

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   logical
   periodical
   cron
   pipeline
   task_status
   scheduler
